<?php

namespace Litepie\Team\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Team\Forms\Type as TypeForm;
use Litepie\Team\Http\Requests\TypeResourceRequest;
use Litepie\Team\Http\Resources\TypeResource;
use Litepie\Team\Http\Resources\TypesCollection;
use Litepie\Team\Models\Type;
use Litepie\Team\Actions\TypeAction;
use Litepie\Team\Actions\TypeActions;


/**
 * Resource controller class for type.
 */
class TypeResourceController extends BaseController
{

    /**
     * Initialize type resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->form = TypeForm::grouped(false)
                        ->setAttributes()
                        ->toArray();
        $this->modules = $this->modules(config('litepie.team.modules'), 'team', guard_url('team'));
    }

    /**
     * Display a list of type.
     *
     * @return Response
     */
    public function index(TypeResourceRequest $request)
    {
        $request = $request->all();
        $page = TypeActions::run('paginate', $request);

        $data = new TypesCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('team::type.names'))
            ->view('team::type.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display type.
     *
     * @param Request $request
     * @param Model   $type
     *
     * @return Response
     */
    public function show(TypeResourceRequest $request, Type $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new TypeResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('team::type.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('team::type.show')
            ->output();
    }

    /**
     * Show the form for creating a new type.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TypeResourceRequest $request, Type $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new TypeResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('team::type.name'))
            ->view('team::type.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new type.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TypeResourceRequest $request, Type $model)
    {
        try {
            $request = $request->all();
            $model = TypeAction::run('store', $model, $request);
            $data = new TypeResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('team::type.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('team/type/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/team/type'))
                ->redirect();
        }

    }

    /**
     * Show type for editing.
     *
     * @param Request $request
     * @param Model   $type
     *
     * @return Response
     */
    public function edit(TypeResourceRequest $request, Type $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new TypeResource($model);
        // return view('team::type.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('team::type.name'))
            ->view('team::type.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the type.
     *
     * @param Request $request
     * @param Model   $type
     *
     * @return Response
     */
    public function update(TypeResourceRequest $request, Type $model)
    {
        try {
            $request = $request->all();
            $model = TypeAction::run('update', $model, $request);
            $data = new TypeResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('team::type.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('team/type/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('team/type/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the type.
     *
     * @param Model   $type
     *
     * @return Response
     */
    public function destroy(TypeResourceRequest $request, Type $model)
    {
        try {

            $request = $request->all();
            $model = TypeAction::run('destroy', $model, $request);
            $data = new TypeResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('team::type.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('team/type/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('team/type/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
